@@ -4,7 +4,7 @@
  * GChemPaint library
  * view.cc
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -38,6 +38,7 @@
 #include <gccv/canvas.h>
 #include <gccv/group.h>
 #include <gccv/text.h>
+#include <gcugtk/ui-manager.h>
 #include <gsf/gsf-output-gio.h>
 #include <gsf/gsf-output-memory.h>
 #include <cairo-pdf.h>
@@ -46,7 +47,6 @@
 #include <pango/pango-context.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
-#include <clocale>
 #include <cmath>
 #include <fstream>
 #include <map>
@@ -96,7 +96,7 @@ View::View (Document *pDoc, bool Embedded):
 	m_height = 300;
 	m_ActiveRichText = NULL;
 	m_bEmbedded = Embedded;
-	m_UIManager = gtk_ui_manager_new ();
+	m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
 	m_Dragging = false;
 	m_pWidget = NULL;
 	m_CurObject = NULL;
@@ -122,7 +122,7 @@ View::~View ()
 		g_free (m_sSmallFontName);
 	pango_font_description_free (m_PangoFontDesc);
 	pango_font_description_free (m_PangoSmallFontDesc);
-	g_object_unref (m_UIManager);
+	delete m_UIManager;
 	// we don't need to delete the canvas, since destroying the widget does the job.
 }
 
@@ -179,13 +179,19 @@ void View::Update (Object *pObject)
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
 	if (client)
 		client->UpdateItem ();
+	// update the links, not that this might result in multiple updates of an object
 	// now, add the children
 	map<string, Object*>::iterator i;
 	Object *child = pObject->GetFirstChild (i);
+	// update the links, not that this might result in multiple updates of an object
 	while (child) {
 		Update (child);
 		child = pObject->GetNextChild (i);
 	}
+	// update the links, not that this might result in multiple updates of an object
+	std::set < gcu::Object * >::iterator j;
+	for (child = pObject->GetFirstLink (j); child; child= pObject->GetNextLink (j))
+		Update (child);
 }
 
 double View::GetZoomFactor ()
@@ -217,9 +223,8 @@ void View::Remove (Object* pObject)
 		return;
 	Object* pObj = pObject->GetMolecule ();
 	if (pObj)
-		m_pData->SelectedObjects.remove (pObj);
-	else
-		m_pData->SelectedObjects.remove (pObject);
+		m_pData->SelectedObjects.erase (pObj);
+	m_pData->SelectedObjects.erase (pObject);
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
 	if (client && client->GetItem ())
 		delete client->GetItem ();
@@ -231,12 +236,13 @@ void View::OnDeleteSelection (GtkWidget* w)
 	Application *pApp = m_pDoc->GetApplication ();
 	Tool *pActiveTool = pApp->GetActiveTool ();
 	Object *parent;
+	std::string parent_id;
 	if (!pActiveTool->DeleteSelection ()) {
 		m_pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
 		Object *pObject, *Group;
-		set<string> ModifiedObjects;
+		set<string> ModifiedObjects, DirtyObjects;
 		bool modify = false;
-		list<Object *>::iterator i, iend = m_pData->SelectedObjects.end ();
+		set < Object * >::iterator i, iend = m_pData->SelectedObjects.end ();
 		// first search if we are deleting top objects or not
 		for (i = m_pData->SelectedObjects.begin (); i != iend; i++)
 			if ((*i)->GetGroup ()) {
@@ -245,24 +251,45 @@ void View::OnDeleteSelection (GtkWidget* w)
 			}
 		Operation *Op = m_pDoc->GetNewOperation (((modify)?
 								GCP_MODIFY_OPERATION: GCP_DELETE_OPERATION));
-		while (!m_pData->SelectedObjects.empty ()) {
-			pObject = m_pData->SelectedObjects.front ();
-			Group = pObject->GetGroup ();
-			if (Group && 
-				(ModifiedObjects.find (Group->GetId ()) == ModifiedObjects.end ())) {
-				Op->AddObject (Group);
-				ModifiedObjects.insert (Group->GetId ());
+		// first save all concerned objects to the operation
+		for (i = m_pData->SelectedObjects.begin (); i != iend; i++) {
+			Group = (*i)->GetGroup ();
+			if (Group) {
+				if (ModifiedObjects.find (Group->GetId ()) == ModifiedObjects.end ()) {
+					Op->AddObject (Group);
+					ModifiedObjects.insert (Group->GetId ());
+				}
 			} else
-				Op->AddObject (pObject);
+				Op->AddObject (*i);
+		}
+		while (!m_pData->SelectedObjects.empty ()) {
+			pObject = *m_pData->SelectedObjects.begin ();
 			pObject->Lock ();
 			parent = pObject->GetParent ();
+			if (parent != m_pDoc)
+				DirtyObjects.insert (parent->GetId ());
 			m_pData->Unselect (pObject);
 			m_pDoc->Remove (pObject);
-			if (parent)
-				parent->EmitSignal (OnChangedSignal);
 		}
 		m_pData->ClearSelection ();
-		set<string>::iterator k, kend = ModifiedObjects.end();
+		set <string> &NewObjects = m_pDoc->GetNewObjects ();
+		set <string>::iterator k, kend;
+		// emit needed signals
+		kend = DirtyObjects.end ();
+		for (k = DirtyObjects.begin (); k != kend; k++) {
+			pObject = m_pDoc->GetDescendant ((*k).c_str ());
+			if (pObject)
+				pObject->EmitSignal (OnChangedSignal);
+		}
+		kend = NewObjects.end ();
+		for (k = NewObjects.begin(); k != kend; k++) {
+			pObject = m_pDoc->GetDescendant ((*k).c_str ());
+			if (!pObject)
+				continue;
+			Group = pObject->GetGroup ();
+			ModifiedObjects.insert ((Group)? Group->GetId (): *k);
+		}
+		kend = ModifiedObjects.end();
 		for (k = ModifiedObjects.begin(); k != kend; k++) {
 			pObject = m_pDoc->GetDescendant ((*k).c_str ());
 			if (pObject)
@@ -325,7 +352,7 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 	switch (*DataType) {
 	case GCP_CLIPBOARD_NATIVE:
 		xml = xmlParseMemory (data, length);
-		m_pDoc->AddData (xml->children->children);
+		m_pDoc->PasteData (xml->children->children);
 		xmlFreeDoc (xml);
 		break;
 	case GCP_CLIPBOARD_UTF8_STRING: {
@@ -376,13 +403,14 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 		dx = m_lastx - (rect.x0 + rect.x1) / 2.;
 		dy = m_lasty - (rect.y0 + rect.y1) / 2.;
 	}
+	m_pData->SimplifySelection ();
 	m_pData->MoveSelection (dx, dy);
 	Tool *pTool = pApp->GetTool ("Select");
 	if (pTool)
 		pTool->AddSelection (m_pData);
 	m_pDoc->PopOperation ();
 	Operation* pOp = m_pDoc->GetNewOperation (GCP_ADD_OPERATION);
-	std::list<Object*>::iterator i, end = m_pData->SelectedObjects.end();
+	std::set < Object * >::iterator i, end = m_pData->SelectedObjects.end();
 	for (i = m_pData->SelectedObjects.begin(); i != end; i++) 
 		pOp->AddObject (*i);
 	m_pDoc->FinishOperation ();
@@ -608,8 +636,8 @@ bool View::OnKeyPress (GtkWidget* w, GdkEventKey* event)
 			if (entries.empty ())
 				break;
 			map<string, Element*>::iterator i, end = entries.end ();
-			g_object_unref (m_UIManager);
-			m_UIManager = gtk_ui_manager_new ();
+			delete m_UIManager;
+			m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
 			GtkActionGroup *group = gtk_action_group_new ("element");
 			GtkAction *action;
 			string ui;
@@ -621,11 +649,11 @@ bool View::OnKeyPress (GtkWidget* w, GdkEventKey* event)
 				gtk_action_group_add_action (group, action);
 				g_object_unref (action);
 				ui = string ("<ui><popup><menuitem action='") + (*i).second->GetSymbol () + "'/></popup></ui>";
-				gtk_ui_manager_add_ui_from_string (m_UIManager, ui.c_str (), -1, NULL);
+				gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), ui.c_str (), -1, NULL);
 			}
-			gtk_ui_manager_insert_action_group (m_UIManager, group, 0);
+			gtk_ui_manager_insert_action_group (m_UIManager->GetUIManager (), group, 0);
 			g_object_unref (group);
-			GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
+			GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/popup");
 			gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
 			break;
 		}
@@ -794,7 +822,6 @@ char *View::BuildSVG ()
 	Render (cr);
 	cairo_destroy (cr);
 	m_pData->ShowSelection (true);
-	gsf_output_write (output, 1, reinterpret_cast < guint8 const * > (""));
 	char *m = g_strdup (reinterpret_cast <char const*> (gsf_output_memory_get_bytes (reinterpret_cast <GsfOutputMemory *> (output))));
 	g_object_unref (output);
 	return m;
@@ -814,7 +841,6 @@ char *View::BuildEPS ()
 	Render (cr);
 	cairo_destroy (cr);
 	m_pData->ShowSelection (true);
-	gsf_output_write (output, 1, reinterpret_cast < guint8 const * > (""));
 	char *m = g_strdup (reinterpret_cast <char const*> (gsf_output_memory_get_bytes (reinterpret_cast <GsfOutputMemory *> (output))));
 	g_object_unref (output);
 	return m;
@@ -956,13 +982,13 @@ bool View::OnButtonPressed (gccv::ItemClient *client, unsigned button, double x,
 	}
 	case 3: {
 		bool result;
-		g_object_unref (m_UIManager);
-		m_UIManager = gtk_ui_manager_new ();
+		delete m_UIManager;
+		m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
 		result = pActiveTool->OnRightButtonClicked (this, m_CurObject, x, y, m_UIManager);
 		if (m_CurObject)
 			result |= m_CurObject->BuildContextualMenu (m_UIManager, m_CurObject, x / GetZoomFactor (), y / GetZoomFactor ());
 		if (result) {
-			GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
+			GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/popup");
 			gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
 			return true;
 		}
@@ -1039,4 +1065,17 @@ void View::SetSelectionState (Object *object, int state)
 	}
 }
 
+void View::GetVisibleArea (double &x0, double &y0, double &x1, double &y1)
+{
+	GtkAdjustment *horiz, *vert;
+	GtkWidget* parent = gtk_widget_get_parent (m_pWidget);
+	double zoom = m_pDoc->GetTheme ()->GetZoomFactor ();
+	horiz = gtk_viewport_get_hadjustment (GTK_VIEWPORT (parent));
+	vert = gtk_viewport_get_vadjustment (GTK_VIEWPORT (parent));
+	x0 = gtk_adjustment_get_value (horiz) / zoom;
+	x1 = x0 + gtk_adjustment_get_page_size (horiz) / zoom;
+	y0 = gtk_adjustment_get_value (vert) / zoom;
+	y1 = y0 + gtk_adjustment_get_page_size (vert) / zoom;
+}
+
 }	//	namespace gcp
