@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/calc/gchemcalc.cc 
  *
- * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,17 +23,17 @@
  */
 
 #include "config.h"
-#include <gcu/application.h>
+#include <gcugtk/application.h>
+#include <gcugtk/filechooser.h>
+#include <gcugtk/printable.h>
+#include <gcugtk/print-setup-dlg.h>
+#include <gcugtk/ui-builder.h>
 #include <gcu/atom.h>
 #include <gcu/bond.h>
 #include <gcu/document.h>
 #include <gcu/element.h>
-#include <gcu/filechooser.h>
 #include <gcu/formula.h>
 #include <gcu/molecule.h>
-#include <gcu/printable.h>
-#include <gcu/print-setup-dlg.h>
-#include <gcu/ui-builder.h>
 #include <gcu/residue.h>
 #include <gcu/value.h>
 #include <glib/gi18n.h>
@@ -49,7 +49,7 @@ using namespace gcu;
 
 using namespace std;
 
-class GChemCalc: public Application, public Printable
+class GChemCalc: public gcugtk::Application, public gcugtk::Printable
 {
 public:
 	GChemCalc ();
@@ -100,14 +100,14 @@ static Object* CreateDocument ()
 }
 
 GChemCalc::GChemCalc ():
-	Application ("gchemcalc"),
+	gcugtk::Application ("gchemcalc"),
 	formula ("")
 {
-	Object::AddType ("atom", CreateAtom, AtomType);
-	Object::AddType ("pseudo-atom", CreateAtom);
-	Object::AddType ("bond", CreateBond, BondType);
-	Object::AddType ("molecule", CreateMolecule, MoleculeType);
-	Object::AddType ("document", CreateDocument, DocumentType);
+	AddType ("atom", CreateAtom, AtomType);
+	AddType ("pseudo-atom", CreateAtom);
+	AddType ("bond", CreateBond, BondType);
+	AddType ("molecule", CreateMolecule, MoleculeType);
+	AddType ("document", CreateDocument, DocumentType);
 	// Load residues
 	xmlDocPtr doc;
 	char *name;
@@ -137,7 +137,7 @@ void GChemCalc::ParseNodes (xmlNodePtr node)
 	while (node) {
 		if (!strcmp ((char*) node->name, "residue")) {
 			r = new Residue ();
-			r->Load (node);
+			r->Load (node, this);
 		}
 		node = node->next;
 	}
@@ -156,13 +156,13 @@ void GChemCalc::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext
 	w = m_GraphWidth;
 	h = m_GraphHeight;
 	switch (GetScaleType ()) {
-	case GCU_PRINT_SCALE_NONE:
+	case gcugtk::GCU_PRINT_SCALE_NONE:
 		break;
-	case GCU_PRINT_SCALE_FIXED:
+	case gcugtk::GCU_PRINT_SCALE_FIXED:
 		w *= Printable::GetScale ();
 		h *= Printable::GetScale ();
 		break;
-	case GCU_PRINT_SCALE_AUTO:
+	case gcugtk::GCU_PRINT_SCALE_AUTO:
 		if (GetHorizFit ())
 			w = width;
 		if (GetVertFit ())
@@ -195,7 +195,7 @@ void GChemCalc::OnSaveAsImage ()
 	l.push_front ("application/postscript");
 	l.push_front ("application/pdf");
 	l.push_front ("image/svg+xml");
-	FileChooser (this, true, l, NULL, _("Save as image"), GetImageSizeWidget ());
+	gcugtk::FileChooser (this, true, l, NULL, _("Save as image"), GetImageSizeWidget ());
 }
 
 bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, G_GNUC_UNUSED Document *pDoc)
@@ -208,7 +208,7 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 			char *unescaped = g_uri_unescape_string (filename, NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchemcalc");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
@@ -275,11 +275,6 @@ static void on_bug (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data
 	App->OnBug ();
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, G_GNUC_UNUSED gpointer data)
-{
-	App->OnWeb (url);
-}
-
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 {
 	const gchar * authors[] = {"Jean Bréfort", NULL};
@@ -299,8 +294,6 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
-	
-	gtk_about_dialog_set_url_hook (on_about_activate_url, NULL, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -317,6 +310,11 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	                       NULL);
 }
 
+static void clear_values (double *values)
+{
+	delete [] values;
+}
+
 static void cb_entry_active (GtkEntry *entry, gpointer data)
 {
 	GError *error;
@@ -429,9 +427,9 @@ static void cb_entry_active (GtkEntry *entry, gpointer data)
 				x[i] = mass + n;
 				y[i] = values[n];
 			}
-			GOData *data = go_data_vector_val_new (x, max, g_free);
+			GOData *data = go_data_vector_val_new (x, max, reinterpret_cast <GDestroyNotify> (clear_values));
 			gog_series_set_dim (App->series, 0, data, &error);
-			data = go_data_vector_val_new (y, max, g_free);
+			data = go_data_vector_val_new (y, max, reinterpret_cast <GDestroyNotify> (clear_values));
 			gog_series_set_dim (App->series, 1, data, &error);
 			g_free (values);
 			// set axis bounds
@@ -462,7 +460,6 @@ static void cb_entry_active (GtkEntry *entry, gpointer data)
 							GTK_DIALOG_DESTROY_WITH_PARENT,
 							GTK_MESSAGE_ERROR,
 							GTK_BUTTONS_OK,
-							"%s",
 							mess);
 		g_signal_connect_swapped (G_OBJECT (w), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (w));
 		gtk_widget_show (w);
@@ -568,7 +565,7 @@ static void on_print_preview ()
 
 static void on_page_setup ()
 {
-	new PrintSetupDlg (App, App);
+	new gcugtk::PrintSetupDlg (App, App);
 }
 
 static void on_save_as_image ()
@@ -715,7 +712,7 @@ int main (int argc, char *argv[])
 	/* Initialize plugins manager */
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
-	UIBuilder *builder = new UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
 	App->window = GTK_WINDOW (builder->GetRefdWidget ("gchemcalc"));
 	gtk_window_set_icon_name (App->window, App->GetIconName ().c_str ());
 	g_signal_connect (GTK_OBJECT (App->window), "destroy",
