@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-app.cc 
  *
- * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,10 +27,10 @@
 #include "gchemtable-curve.h"
 #include "gchemtable-data.h"
 #include "gchemtable-elt.h"
+#include <gcugtk/filechooser.h>
+#include <gcugtk/ui-builder.h>
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
-#include <gcu/filechooser.h>
-#include <gcu/ui-builder.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtkaboutdialog.h>
@@ -102,11 +102,6 @@ static void on_block_colors (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *App
 	App->SetColorScheme ("block");
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, gpointer data)
-{
-	reinterpret_cast <Application *> (data)->OnWeb (url);
-}
-
 static void on_help (G_GNUC_UNUSED GtkWidget *widget, GChemTableApp *app)
 {
 	app->OnHelp ();
@@ -299,7 +294,7 @@ static void on_destroy (GChemTableApp *App)
 	gtk_main_quit ();
 }
 
-GChemTableApp::GChemTableApp (): Application ("gchemtable")
+GChemTableApp::GChemTableApp (): gcugtk::Application ("gchemtable")
 {
 	GtkVBox* vbox;
 
@@ -346,7 +341,7 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 	colorschemes["none"] = GCU_PERIODIC_COLOR_NONE;
 	colorschemes["default"] = GCU_PERIODIC_COLOR_DEFAULT;
 
-	UIBuilder *builder = new UIBuilder (UIDIR"/state-thermometer.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/state-thermometer.ui", GETTEXT_PACKAGE);
 	GtkWidget *thermometer = builder->GetRefdWidget ("state-thermometer");
 	colorschemes["state"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_state_color, thermometer, this);
 	gtk_widget_show_all (thermometer);
@@ -355,7 +350,7 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 	temperature = gtk_range_get_value (GTK_RANGE (thermometer));
 	delete builder;
 
-	builder = new UIBuilder (UIDIR"/family.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/family.ui", GETTEXT_PACKAGE);
 	GtkWidget *familywidget = builder->GetRefdWidget ("family-legend");
 	colorschemes["family"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_family_color, familywidget, this);	
 	gtk_widget_show_all (familywidget);
@@ -365,7 +360,7 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 	g_signal_connect (G_OBJECT (familywidget), "changed", G_CALLBACK (on_changed_family), this);
 	delete builder;
 
-	builder = new UIBuilder (UIDIR"/acidity.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/acidity.ui", GETTEXT_PACKAGE);
 	GtkWidget *aciditylegend = builder->GetRefdWidget ("acidity-legend");
 	colorschemes["acidity"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_acidity_color, aciditylegend, this);
 	gtk_widget_show_all (aciditylegend);
@@ -375,7 +370,7 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 
 	colorschemes["radius"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_radius_color, NULL, this);
 
-	builder = new UIBuilder (UIDIR"/block.ui", GETTEXT_PACKAGE);
+	builder = new gcugtk::UIBuilder (UIDIR"/block.ui", GETTEXT_PACKAGE);
 	GtkWidget *blocklegend = builder->GetRefdWidget ("block-legend");
 	colorschemes["block"] = gcu_periodic_add_color_scheme (periodic, (GcuPeriodicColorFunc) get_block_color, blocklegend, this);
 	gtk_widget_show_all (blocklegend);
@@ -412,8 +407,6 @@ void GChemTableApp::OnAbout ()
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301\n"
 		"USA";
-	
-	gtk_about_dialog_set_url_hook (on_about_activate_url, this, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -436,7 +429,7 @@ void GChemTableApp::OnElement (int Z)
 		return;
 	int t = Z - 1;
 	if (Pages[t] != NULL)
-		gtk_window_present (Pages[t]->GetWindow ());
+		Pages[t]->Present ();
 	else
 		Pages[t] = new GChemTableElt (this, Z);
 }
@@ -722,7 +715,7 @@ void GChemTableApp::OnSaveAsImage (GChemTableCurve *curve)
 	l.push_front ("application/postscript");
 	l.push_front ("application/pdf");
 	l.push_front ("image/svg+xml");
-	FileChooser (this, true, l, reinterpret_cast <Document *> (curve), _("Save as image"), GetImageSizeWidget ());
+	gcugtk::FileChooser (this, true, l, reinterpret_cast <Document *> (curve), _("Save as image"), GetImageSizeWidget ());
 }
 
 bool GChemTableApp::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, Document *Doc)
@@ -736,7 +729,7 @@ bool GChemTableApp::FileProcess (const gchar* filename, const gchar* mime_type,
 			char *unescaped = g_uri_unescape_string (filename, NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
